This is the python ``mmgroup`` project.

It gives the user the capability to compute in the Monster group.
In mathematics, the Monster group is the largest finite sporadic
simple group.

Project Documentation see

https://mmgroup.readthedocs.io/en/latest/

Quick installation and test
---------------------------

For Windows 64:

.. code-block::

   pip install mmgroup
   pip install pytest
   python -m pytest --pyargs -Wignore mmgroup -m "not slow"

For Linux and macOS:

.. code-block::

   pip3 install mmgroup
   pip3 install pytest
   python3 -m pytest --pyargs -Wignore mmgroup -m "not slow"


License
-------

Copyright Martin Seysen, 2020.

Distributed under the terms of the MIT license, mmgroup is free and 
open source software.

https://github.com/Martin-Seysen/test_repository/blob/master/LICENSE



